@@ -31,7 +31,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.39';
+our $VERSION = '2.40';
 
 =head1 SYNOPSIS
 
@@ -167,7 +167,6 @@ has afterok => (
 );
 
 
-
 =head2 cpus_per_task
 
 slurm item --cpus_per_task defaults to 4, which is probably fine
@@ -363,6 +362,27 @@ has 'use_gnuparallel' => (
     documentation => q{Use gnu-parallel to run jobs and manage threads. This is the best option if you do not know how many threads your application uses!}
 );
 
+=head2 use_custom
+
+Use a custom command
+
+=cut
+
+has 'use_custom' => (
+    is => 'rw',
+    isa => 'Bool',
+    default => 0,
+    required => 0,
+    documentation => q{Use custom command to run jobs},
+);
+
+has 'custom_command' => (
+    is => 'rw',
+    isa => 'Str',
+    predicate => 'has_custom_command',
+    default => q{},
+);
+
 =head1 Internal Variables
 
 You should not need to mess with any of these.
@@ -741,9 +761,12 @@ sub parse_file_slurm{
         my $line = $_;
         next unless $line;
         next unless $line =~ m/\S/;
+        if($line =~ m/^#HPC/){
+            $self->check_meta($line);
+        }
         next if $line =~ m/^#/;
 
-        $DB::single=2;
+        #$DB::single=2;
 
         #Do a sanity check for nohup
         if($line =~ m/^nohup/){
@@ -802,6 +825,31 @@ sub parse_file_slurm{
     push(@{$self->jobref}, []) if $self->serial;
 }
 
+=head2 check_meta
+
+allow for changing parameters mid through the script
+
+#Job1
+echo "this is job one" && \
+    bin/dostuff bblahblahblah
+
+#HPC cpu_per_task=12
+
+echo "This is my new job with new HPC params!"
+
+=cut
+
+
+sub check_meta{
+    my $self = shift;
+    my $line = shift;
+
+    my(@match) = $line =~ m/HPC (\w+)=(\w+)/;
+    $DB::single=2;
+    my($t1, $t2)  = ($match[0], $match[1]);
+    $self->$t1($t2);
+}
+
 =head2 work
 
 Get the node #may be removed but we'll try it out
@@ -867,6 +915,7 @@ sub process_batch{
             AFTEROK => $ok,
             OUT => $self->logdir."/".$self->jobname."_".$self->batch_counter.".log",
             MODULE => $self->module,
+            self => $self,
             COMMAND => $command },
         $self->slurmfile
     ) || die $self->template->error;
@@ -892,6 +941,10 @@ sub process_batch_command {
     #Need to get absolute path going on...
     #$self->cmdfile($self->jobname."_batch".$self->batch_counter.".in");
 
+    if($self->has_custom_command){
+        $command = "cd ".getcwd()."\n";
+        $command .= $self->custom_command." --procs ".$self->procs." --infile ".$self->cmdfile." --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter;
+    }
     if($self->use_gnuparallel){
         $command = "cd ".getcwd()."\n";
         $command .= "cat ".$self->cmdfile." | parallelparser.pl | parallel --joblog ".$self->outdir."/main.log --gnu -N 1 -q  gnuparallelrunner.pl --command `echo {}` --outdir ".$self->outdir." --logname ".$self->jobname."_".$self->batch_counter."\n";
